@@ -1252,6 +1252,9 @@ class PlaceService(BaseRdbmsService):
 
         :return:
         """
+        if not place_ids:
+            return []
+
         with self.acquire_rdbms_connection(auto_commit=False, connection=connection) as connection:
             cursor = connection.execute(
                 """
@@ -1677,13 +1680,8 @@ class PlaceService(BaseRdbmsService):
                 raise ValueError("The element of the argument 'keywords' MUST be strings")
             keywords = string_util.string_to_keywords(keywords, keyword_minimal_length=2)
 
-        if isinstance(categories, str):
+        if not isinstance(categories, (list, set, tuple)):
             categories = [categories]
-        else:
-            if not isinstance(categories, (list, set, tuple)):
-                raise ValueError("The argument 'categories' MUST be a string, a list, a set, or a tuple")
-            if any(not isinstance(category, str) for category in categories):
-                raise ValueError("The element of the argument 'categories' MUST be strings")
 
         #
         if bounding_box:
@@ -1756,7 +1754,6 @@ class PlaceService(BaseRdbmsService):
                              OR (%(area_id)s IS NOT NULL 
                                  AND ST_Contains(get_area_boundaries(%(area_id)s), location)))                      
                       ORDER BY
-                        score ASC,
                         place_id DESC
                       LIMIT %(limit)s
                       OFFSET %(offset)s
@@ -1785,7 +1782,7 @@ class PlaceService(BaseRdbmsService):
             }
 
             places = self.get_places(
-                places_dict.keys(),
+                list(places_dict.keys()),
                 account_id=account_id,
                 connection=connection,
                 include_address=include_address,
